==> VE-SDK-0.5.0.zip: org/eclipse/ve/internal/java/codegen/java/rules/EventProcessingRule.java <==
/*******************************************************************************
 * Copyright (c)  2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 *  $RCSfile: EventProcessingRule.java,v $
 *  $Revision: 1.1 $  $Date: 2003/10/27 17:48:30 $ 
 */
package org.eclipse.ve.internal.java.codegen.java.rules;

import org.eclipse.jdt.internal.compiler.ast.AbstractMethodDeclaration;
import org.eclipse.ve.internal.cde.rules.IRuleRegistry;

import org.eclipse.ve.internal.java.codegen.model.BeanPart;

/**
 * @author Gili Mendel
 *
 */
public class EventProcessingRule implements IEventProcessingRule {
	
	public final static String EVENT_INIT_METHOD = "initConnections" ; //$NON-NLS-1$

	/**
	 * @see org.eclipse.ve.internal.java.codegen.java.rules.IEvenProcessingRule#parseForEvents(AbstractMethodDeclaration, BeanPart)
	 */
	public boolean parseForEvents(AbstractMethodDeclaration method, BeanPart bp) {
        // Parse this method for events, if it is the init method, or if it is a initConnection JCMMethod.		                                   
		if (EVENT_INIT_METHOD.equals(new String(method.selector))) { 
			if (method.arguments == null)
			  return true ;
		}	
		else if (bp.isInitMethod(method))
		    return true ;
	    return false ;
	}
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.java.codegen.java.rules.IEventProcessingRule#isEventInitMethodSigniture(java.lang.String)
	 */
	public boolean isEventInitMethodSigniture(String methodName) {
		return EVENT_INIT_METHOD.equals(methodName) ;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.cde.rules.IRule#setRegistry(org.eclipse.ve.internal.cde.rules.IRuleRegistry)
	 */
	public void setRegistry(IRuleRegistry registry) {
		// no-op. We don't care.
	}	

}

==> VE-SDK-1.0.2.2.zip: org/eclipse/ve/internal/java/codegen/java/rules/EventProcessingRule.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 *  $RCSfile: EventProcessingRule.java,v $
 *  $Revision: 1.3 $  $Date: 2004/08/27 15:34:10 $ 
 */
package org.eclipse.ve.internal.java.codegen.java.rules;

import org.eclipse.jdt.core.dom.MethodDeclaration;

import org.eclipse.ve.internal.cde.rules.IRuleRegistry;

import org.eclipse.ve.internal.java.codegen.model.BeanPart;

/**
 * @author Gili Mendel
 *
 */
public class EventProcessingRule implements IEventProcessingRule {
	
	public final static String EVENT_INIT_METHOD = "initConnections" ; //$NON-NLS-1$

	/**
	 * @see org.eclipse.ve.internal.java.codegen.java.rules.IEvenProcessingRule#parseForEvents(AbstractMethodDeclaration, BeanPart)
	 */
	public boolean parseForEvents(MethodDeclaration method, BeanPart bp) {
        // Parse this method for events, if it is the init method, or if it is a initConnection JCMMethod.		                                   
		if (EVENT_INIT_METHOD.equals(method.getName().getIdentifier())) { 
			if (method.parameters().size() == 0)
			  return true ;
		}	
		else if (bp.isInitMethod(method))
		    return true ;
	    return false ;
	}
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.java.codegen.java.rules.IEventProcessingRule#isEventInitMethodSigniture(java.lang.String)
	 */
	public boolean isEventInitMethodSigniture(String methodName) {
		return EVENT_INIT_METHOD.equals(methodName) ;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.cde.rules.IRule#setRegistry(org.eclipse.ve.internal.cde.rules.IRuleRegistry)
	 */
	public void setRegistry(IRuleRegistry registry) {
		// no-op. We don't care.
	}	

}
